@@ -1,5 +1,5 @@
 package App::bmkpasswd;
-$App::bmkpasswd::VERSION = '2.012001';
+$App::bmkpasswd::VERSION = '2.012002';
 use strictures 2;
 use Carp;
 use Try::Tiny;
@@ -19,7 +19,10 @@ our @EXPORT_OK = qw/
   mkpasswd_forked
 /;
 
-use Bytes::Random::Secure::Tiny;
+{ local @INC = @INC;
+  pop @INC if $INC[-1] eq '.';
+  require Bytes::Random::Secure::Tiny;
+}
 my ($brs, $brsnb);
 sub get_brs {
   my (%params) = @_;
